==> icedtea-web_1.4.orig.tar.gz: icedtea-web-1.4/tests/reproducers/signed/DeploymentPropertiesAreExposed/testcases/DeploymentPropertiesAreExposedTest.java <==
/* DeploymentPropertiesAreExposedTest.java
Copyright (C) 2012 Red Hat, Inc.

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as published by
the Free Software Foundation, version 2.

IcedTea is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
 */

import static org.junit.Assert.*;

import java.io.File;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import net.sourceforge.jnlp.ServerAccess;
import org.junit.Test;

public class DeploymentPropertiesAreExposedTest {


    @Test
    public void verifyDeploymentConfigrationIsExposedAsSystemProperties() throws Exception {
        ServerAccess server = new ServerAccess();
        List<String> trustCertificates = Arrays.asList(new String[] {"-Xtrustall"});

        ServerAccess.ProcessResult result = server.executeJavawsHeadless(
            trustCertificates, "/DeploymentPropertiesAreExposed.jnlp");

        String expectedRegex = ".*" + File.separator + ".icedtea" + File.separator + "log" + ".*";
        String actual = result.stdout.trim();

        boolean stdOutMatches = actual.matches(expectedRegex);

        assertTrue("'" + actual + "' should match '" + expectedRegex + "' but did not", stdOutMatches);
    }

}

==> icedtea-web_1.5.3.orig.tar.gz: icedtea-web-1.5.3/tests/reproducers/signed/DeploymentPropertiesAreExposed/testcases/DeploymentPropertiesAreExposedTest.java <==
/* DeploymentPropertiesAreExposedTest.java
Copyright (C) 2012 Red Hat, Inc.

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as published by
the Free Software Foundation, version 2.

IcedTea is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
 */

import static org.junit.Assert.*;

import java.io.File;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import net.sourceforge.jnlp.ServerAccess;
import net.sourceforge.jnlp.ProcessResult;
import net.sourceforge.jnlp.runtime.JNLPRuntime;
import net.sourceforge.jnlp.config.DeploymentConfiguration;
import org.junit.Test;

public class DeploymentPropertiesAreExposedTest {

    @Test
    public void verifyDeploymentConfigrationIsExposedAsSystemProperties() throws Exception {
        ServerAccess server = new ServerAccess();
        List<String> trustCertificates = Arrays.asList(new String[] {"-Xtrustall"});

        ProcessResult result = server.executeJavawsHeadless(
            trustCertificates, "/DeploymentPropertiesAreExposed.jnlp");

        DeploymentConfiguration config = JNLPRuntime.getConfiguration();
        config.load();
        String userLogDir = config.getProperty(DeploymentConfiguration.KEY_USER_LOG_DIR);
        String expectedRegex = userLogDir + "/?";
        String actual = result.stdout.trim();

        boolean stdOutMatches = actual.matches(expectedRegex);

        assertTrue("'" + actual + "' should match '" + expectedRegex + "' but did not", stdOutMatches);
    }

}
